/**********************************************************************
** Copyright (C) 2002 Bill Wetter  All rights reserved.
**
**
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** 
** Contact billw@tinyapp.com  with any problems or if any conditions of this 
** licensing are not clear to you.
**
**********************************************************************/

#include <qpopupmenu.h>
#include <qmessagebox.h>
#include <qpe/qpeapplication.h>

#include "mainwidget.h"


void MainWidget::quit ()
{

	// Put quit sequence here

}

void MainWidget::newGame()
{

	for(int q=0;q < 45; q++){
		if(MyPieceList[q]->frame() == 1){
			if(q == 22){
				MyPieceList[q]->setFrame(1);
			} else {
				MyPieceList[q]->setFrame(0);
			}
		}
	}
	MyPieceList[22]->setFrame(1);
	MyCanvas->update();


}

void MainWidget::setUpBoard ()
{
	QString path = QPEApplication::qpeDir() + "pics/ziq/";

	iqImages = new QCanvasPixmapArray(path + "iqpic%1.png", 2);

	/** Create the ball/sprite that will be used during the drag **/
	DragPiece = new QCanvasSprite(iqImages, MyCanvas);
	DragPiece->move(325, 325); // set it off stage 
	DragPiece->show();

	/** Place top pieces **/
	int startX =82;
	int startY =19; 
	for(int i=0; i < 9; i++){
		MyPieceList[i]= new QGamePiece(MyCanvas, iqImages);
		MyPieceList[i]->numInList = i;
		MyPieceList[i]->move(startX,startY);
		MyPieceList[i]->show();
		startX=startX+25;
		if(i == 2 || i == 5){
			startX=82;
			startY=startY+25;
		}
	}
	/** Place midsection pieces **/
	startX = 7;
	startY = startY+25;
	for(int j=9; j < 36; j++){
		MyPieceList[j]= new QGamePiece(MyCanvas, iqImages);
		MyPieceList[j]->numInList = j;
		MyPieceList[j]->move(startX,startY);
		MyPieceList[j]->show();
		startX=startX+25;
		if(j == 17 || j == 26){
			startX=7;
			startY=startY+25;
		}
	}
	
	/** Place bottom pieces **/
	startX = 82;
	startY = startY+25;
	for(int j=36; j < 45; j++){
		MyPieceList[j]= new QGamePiece(MyCanvas, iqImages);
		MyPieceList[j]->numInList = j;
		MyPieceList[j]->move(startX,startY);
		MyPieceList[j]->show();
		startX=startX+25;
		if(j == 38 || j == 41){
			startX=82;
			startY=startY+25;
		}
	}


	/** Make a list for each of the pieces to show where it can jump too **/
	/* this will start main list of pieces to check */
	for(int i = 0; i < 45; i++){

		MyPieceList[i]->jumpList[0] = 0;
		MyPieceList[i]->jumpList[1] = 0;
		MyPieceList[i]->jumpList[2] = 0;
		MyPieceList[i]->jumpList[3] = 0;

		/* this is the list of pieces it is checking against */
		for(int h = 0; h < 45; h++){

			if(MyPieceList[i]->x() == MyPieceList[h]->x()) {
				if( ( MyPieceList[i]->y() ) - 50 == MyPieceList[h]->y() || ( MyPieceList[i]->y() ) + 50 == MyPieceList[h]->y() ) {
					
					// add this number to its list
					for(int r = 0; r < 4; r++){
						if(MyPieceList[i]->jumpList[r] == 0){
							MyPieceList[i]->jumpList[r] = h;
							r = 5;
						}
					}
				}
			}
			
			if( MyPieceList[i]->y() == MyPieceList[h]->y() ) {
				if( ( MyPieceList[i]->x() ) - 50 == MyPieceList[h]->x() || ( MyPieceList[i]->x() ) + 50 == MyPieceList[h]->x() ) {
					
					// add this number to its list
					for(int r = 0; r < 4; r++){
						if(MyPieceList[i]->jumpList[r] == 0){
							MyPieceList[i]->jumpList[r] = h;
							r=5;
						}
					}
				}
			}
		} /* ends inner for loop */

	} /* ends top for loop */

	/** Set middle piece empty **/
	MyPieceList[22]->setFrame(1);

}

void MainWidget::makeMenu()
{
	


}

MainWidget::MainWidget( QWidget* parent,  const char* name,
              WFlags fl )
  : QWidget( parent, name, fl )
{
	
	if ( !name ) setName( "zIQ" );
	setCaption( tr("zIQ") );

	/** Creates menus on top of screen **/
	QPopupMenu* file = new QPopupMenu( this );
	CHECK_PTR( file );
	file->insertItem(tr("New Game"), this, SLOT(newGame()));


	QPopupMenu* help = new QPopupMenu( this );
	CHECK_PTR( help );
	help->insertItem(tr("How to play"), this, SLOT(InstructBox()));
	help->insertItem(tr("About"), this, SLOT(AboutBox()));

	menu = new QMenuBar( this );
 	CHECK_PTR( menu );
  menu->insertItem( tr("&File"), file );
	menu->insertItem( tr("&Help"), help );
	
	
	/** Creates Canvas where all objects will be placed **/
	MyCanvas = new QCanvas(this);  //initialize canvas
	MyCanvas->resize(236, 260);	// set the size
	MyCanvas->setBackgroundColor( QColor (0, 0, 102 )  );
	
	setUpBoard();
	
	/** Initialize the view of our canvas so we can see da good stuff **/

	MyView = new QMyView(MyCanvas, this);
	MyView->setFrameStyle(QFrame::Panel | QFrame::Sunken);
	MyView->setHScrollBarMode(QScrollView::AlwaysOff);
	MyView->setVScrollBarMode(QScrollView::AlwaysOff);
	MyView->setPalette( QPalette ( QColor (0, 0, 102 )  ) );
	MyView->move(0,24);
	MyView->adjustSize();
	MyView->setDragPiece(DragPiece);
	MyView->show();


}


void MainWidget::AboutBox()
{
	QMessageBox::about(this, tr("About zIQ"),
		tr("<b>zIQ</b><br>"
			"This is the classic IQ game.<br>"
			"<br>"
			"Maintained by: Bill Wetter (July 2002)<br>"
			"To Report Bugs email: billw@tinyapp.com<br>"
			"Web Site: http://www.tinyapp.com<br>"
			"<br>"
			"This version was modified and translated by:<br>"
			"Peter Hildebrandt and Robert Ernst<br>"
			"<br>"
			"This software can be distributed "
			"freely under GPL licensing."));
}

void MainWidget::InstructBox()
{
	QMessageBox::information(this, tr("How to play zIQ"),
		tr("How to Play:<br><br>"
			"Jump one piece at a time "
			"either horizontally or vertically. "
			"The objective is to leave as few "
			"pieces as possible on the board.<br><br>"
			"Ranking:<br>"
			"5+: You need practice.<br>"
			"4: Good Job.<br>"
			"3: Above average.<br>"
			"2: You are closing in on genius.<br>"
			"1: You are a genius!"));
}
















